# Generated by roxygen2: do not edit by hand

S3method("$",tcc_compiled)
S3method(as.character,tcc_cstring)
S3method(print,tcc_callback)
S3method(print,tcc_compiled)
S3method(print,tcc_cstring)
S3method(print,tcc_ffi)
export(blas_lapack_info)
export(get_external_ptr_addr)
export(tcc_add_file)
export(tcc_add_include_path)
export(tcc_add_library)
export(tcc_add_library_path)
export(tcc_add_symbol)
export(tcc_add_sysinclude_path)
export(tcc_bin_path)
export(tcc_bind)
export(tcc_call_symbol)
export(tcc_callback)
export(tcc_callback_async_drain)
export(tcc_callback_async_schedule)
export(tcc_callback_close)
export(tcc_callback_ptr)
export(tcc_callback_valid)
export(tcc_cli)
export(tcc_compile)
export(tcc_compile_string)
export(tcc_container_of)
export(tcc_cstring)
export(tcc_cstring_object)
export(tcc_data_ptr)
export(tcc_enum)
export(tcc_ffi)
export(tcc_field_addr)
export(tcc_free)
export(tcc_generate_bindings)
export(tcc_get_symbol)
export(tcc_global)
export(tcc_header)
export(tcc_include)
export(tcc_include_path)
export(tcc_include_paths)
export(tcc_introspect)
export(tcc_lib_path)
export(tcc_lib_paths)
export(tcc_library)
export(tcc_library_path)
export(tcc_link)
export(tcc_list_symbols)
export(tcc_malloc)
export(tcc_map_c_type_to_ffi)
export(tcc_null_ptr)
export(tcc_options)
export(tcc_output)
export(tcc_output_file)
export(tcc_path)
export(tcc_prefix)
export(tcc_ptr_addr)
export(tcc_ptr_free_set_null)
export(tcc_ptr_is_null)
export(tcc_ptr_is_owned)
export(tcc_ptr_set)
export(tcc_read_bytes)
export(tcc_read_cstring)
export(tcc_read_f32)
export(tcc_read_f64)
export(tcc_read_i16)
export(tcc_read_i32)
export(tcc_read_i64)
export(tcc_read_i8)
export(tcc_read_ptr)
export(tcc_read_u16)
export(tcc_read_u32)
export(tcc_read_u64)
export(tcc_read_u8)
export(tcc_recompile)
export(tcc_relocate)
export(tcc_run_cli)
export(tcc_set_options)
export(tcc_source)
export(tcc_state)
export(tcc_struct)
export(tcc_struct_raw_access)
export(tcc_symbol_is_valid)
export(tcc_sysinclude_paths)
export(tcc_treesitter_bindings)
export(tcc_treesitter_defines)
export(tcc_treesitter_enum_bindings)
export(tcc_treesitter_enum_members)
export(tcc_treesitter_enums)
export(tcc_treesitter_functions)
export(tcc_treesitter_global_types)
export(tcc_treesitter_globals)
export(tcc_treesitter_struct_accessors)
export(tcc_treesitter_struct_bindings)
export(tcc_treesitter_struct_members)
export(tcc_treesitter_structs)
export(tcc_treesitter_union_accessors)
export(tcc_treesitter_union_bindings)
export(tcc_treesitter_union_members)
export(tcc_treesitter_unions)
export(tcc_union)
export(tcc_write_bytes)
export(tcc_write_f32)
export(tcc_write_f64)
export(tcc_write_i16)
export(tcc_write_i32)
export(tcc_write_i64)
export(tcc_write_i8)
export(tcc_write_ptr)
export(tcc_write_u16)
export(tcc_write_u32)
export(tcc_write_u64)
export(tcc_write_u8)
importFrom(lambda.r,"%as%")
importFrom(lambda.r,UseFunction)
useDynLib(Rtinycc, .registration = TRUE)
