% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tcc_ptr_utils.R
\name{tcc_null_ptr}
\alias{tcc_null_ptr}
\title{Create a NULL pointer}
\usage{
tcc_null_ptr()
}
\value{
An external pointer with NULL address
}
\description{
Creates a NULL pointer equivalent for use with FFI functions that expect
optional pointer arguments.
}
