% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tinycc.R
\name{tcc_symbol_is_valid}
\alias{tcc_symbol_is_valid}
\title{Check if a tcc_symbol external pointer is valid}
\usage{
tcc_symbol_is_valid(ptr)
}
\arguments{
\item{ptr}{External pointer from \code{tcc_get_symbol()}.}
}
\value{
TRUE if the pointer address is non-null, FALSE otherwise.
}
\description{
Check if a tcc_symbol external pointer is valid
}
