% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ffi.R
\name{tcc_library}
\alias{tcc_library}
\title{Add library to link against}
\usage{
tcc_library(ffi, library)
}
\arguments{
\item{ffi}{A tcc_ffi object}

\item{library}{Library name (e.g., "m", "sqlite3") or a path to a
shared library (e.g., "libm.so.6"). When a path or platform library file
name is provided, the library directory is added automatically and TinyCC
is asked to link that exact file name. This keeps versioned runtime
libraries such as \code{libm.so.6} distinct from generic linker names such as
\code{m}/\code{libm.so}.}
}
\value{
Updated tcc_ffi object (for chaining)
}
\description{
Add library to link against
}
