% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tinycc.R
\name{tcc_include_paths}
\alias{tcc_include_paths}
\alias{tcc_sysinclude_paths}
\title{TinyCC include search paths}
\usage{
tcc_include_paths()

tcc_sysinclude_paths()
}
\value{
A character vector of include directories.
}
\description{
Returns the include directories used by the bundled TinyCC (top-level include and lib/tcc/include).
}
