% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tcc_ptr_utils.R
\name{tcc_read_ptr}
\alias{tcc_read_ptr}
\title{Read a pointer at byte offset}
\usage{
tcc_read_ptr(ptr, offset = 0L)
}
\arguments{
\item{ptr}{External pointer}

\item{offset}{Byte offset from \code{ptr} (scalar interface). Ignored when
\code{n} is supplied.}
}
\value{
External pointer
}
\description{
Dereferences a \verb{void*} at the given byte offset from \code{ptr}.
Equivalent to \verb{*(void**)(ptr + offset)}. The returned pointer
is tagged \code{"rtinycc_borrowed"} and will not be freed by the
garbage collector.
}
