% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tcc_ptr_utils.R
\name{tcc_ptr_set}
\alias{tcc_ptr_set}
\title{Set a pointer-to-pointer value}
\usage{
tcc_ptr_set(ptr_ref, ptr_value)
}
\arguments{
\item{ptr_ref}{External pointer to a pointer value (e.g., address of a field).}

\item{ptr_value}{External pointer to store.}
}
\value{
The updated pointer reference (invisibly).
}
\description{
Assigns the address in \code{ptr_value} to the location pointed to by \code{ptr_ref}.
}
