% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tinycc.R
\name{tcc_call_symbol}
\alias{tcc_call_symbol}
\title{Call a zero-argument symbol with a specified return type}
\usage{
tcc_call_symbol(state, name, return = c("int", "double", "void"))
}
\arguments{
\item{state}{A \code{tcc_state}.}

\item{name}{Symbol name to call.}

\item{return}{One of "int", "double", "void".}
}
\value{
The return value cast to the requested type (NULL for void).
}
\description{
Call a zero-argument symbol with a specified return type
}
