% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/treesitter_helpers.R
\name{tcc_treesitter_enum_members}
\alias{tcc_treesitter_enum_members}
\title{Parse enum members with treesitter.c}
\usage{
tcc_treesitter_enum_members(header, ...)
}
\arguments{
\item{header}{Character scalar containing C declarations.}

\item{...}{Additional arguments passed to \code{treesitter.c::get_enum_members_from_root()}.}
}
\value{
A data frame of enum members.
}
\description{
Parse enum members with treesitter.c
}
\examples{
\dontrun{
header <- "enum status { OK = 0, ERR = 1 };"
tcc_treesitter_enum_members(header)
}
}
