% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ffi.R
\name{tcc_struct_raw_access}
\alias{tcc_struct_raw_access}
\title{Enable raw byte access for struct}
\usage{
tcc_struct_raw_access(ffi, struct_name)
}
\arguments{
\item{ffi}{A tcc_ffi object}

\item{struct_name}{Struct name}
}
\value{
Updated tcc_ffi object
}
\description{
Generates helper functions to read/write raw bytes from struct memory.
Useful for bitwise operations, debugging, or manual serialization.
}
