% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/treesitter_helpers.R
\name{tcc_treesitter_struct_members}
\alias{tcc_treesitter_struct_members}
\title{Parse struct members (including bitfields) with treesitter.c}
\usage{
tcc_treesitter_struct_members(header, ...)
}
\arguments{
\item{header}{Character scalar containing C declarations.}

\item{...}{Additional arguments passed to \code{treesitter.c::get_struct_members()}.}
}
\value{
A data frame of struct members.
}
\description{
Parse struct members (including bitfields) with treesitter.c
}
\examples{
\dontrun{
header <- "struct point { double x; double y; };"
tcc_treesitter_struct_members(header)
}
}
