% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ffi.R
\name{tcc_ffi}
\alias{tcc_ffi}
\title{Create a new FFI compilation context}
\usage{
tcc_ffi()
}
\value{
A tcc_ffi object with chaining support
}
\description{
Initialize a Bun-style FFI context for API-mode compilation.
This is the entry point for the modern FFI API.
}
\examples{
ffi <- tcc_ffi()
}
