% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tcc_ptr_utils.R
\name{tcc_data_ptr}
\alias{tcc_data_ptr}
\title{Dereference a pointer-to-pointer}
\usage{
tcc_data_ptr(ptr_ref)
}
\arguments{
\item{ptr_ref}{External pointer to a pointer value (e.g., address of a field).}
}
\value{
An external pointer tagged \code{"rtinycc_borrowed"}. Not owned by
Rtinycc and never freed on garbage collection. Do not pass to
\code{\link[=tcc_free]{tcc_free()}}.
}
\description{
Treats \code{ptr_ref} as a pointer to a pointer and returns the pointed address
as an external pointer. This is useful for fields like \verb{void**} or \verb{T**}.
}
