% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ffi.R
\name{print.tcc_ffi}
\alias{print.tcc_ffi}
\title{Print tcc_ffi object}
\usage{
\method{print}{tcc_ffi}(x, ...)
}
\arguments{
\item{x}{A tcc_ffi object}

\item{...}{Ignored}
}
\value{
The input \code{tcc_ffi} object, invisibly. Called for its side
effect of printing the configured output mode, registered symbols,
and selected libraries/include paths.
}
\description{
Print tcc_ffi object
}
