% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ffi.R
\name{tcc_options}
\alias{tcc_options}
\title{Add TinyCC compiler options to FFI context}
\usage{
tcc_options(ffi, options)
}
\arguments{
\item{ffi}{A tcc_ffi object}

\item{options}{Character vector of option fragments}
}
\value{
Updated tcc_ffi object (for chaining)
}
\description{
Append raw options that are passed to \code{tcc_set_options()} before compiling
generated wrappers (for example \code{"-O2"} or \code{"-Wall"}).
}
