% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ffi.R
\name{tcc_introspect}
\alias{tcc_introspect}
\title{Enable introspection helpers}
\usage{
tcc_introspect(ffi)
}
\arguments{
\item{ffi}{A tcc_ffi object}
}
\value{
Updated tcc_ffi object
}
\description{
Generates sizeof, alignof, and offsetof helper functions for
structs, unions, and enums. Useful for debugging or when you need
to know C layout information from R.
}
