% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tcc_ptr_utils.R
\name{tcc_write_u32}
\alias{tcc_write_u32}
\title{Write an unsigned 32-bit integer}
\usage{
tcc_write_u32(ptr, offset, value)
}
\arguments{
\item{ptr}{External pointer}

\item{offset}{Byte offset}

\item{value}{Integer value to write}
}
\value{
\code{NULL} (invisibly). Called for its side effect of writing one
unsigned 32-bit value into native memory at \code{ptr + offset}.
}
\description{
Write an unsigned 32-bit integer
}
