% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tcc_ptr_utils.R
\name{tcc_ptr_free_set_null}
\alias{tcc_ptr_free_set_null}
\title{Free the pointed memory and set to NULL}
\usage{
tcc_ptr_free_set_null(ptr_ref)
}
\arguments{
\item{ptr_ref}{External pointer to a pointer value.}
}
\value{
The updated pointer reference (invisibly).
}
\description{
Frees the memory pointed to by \code{ptr_ref} and sets the pointer to NULL.
Use this only when the pointed memory is not already owned by another
external pointer with its own finalizer.
}
